@@ -187,7 +187,8 @@ FeedList::FeedList(Backend::Storage *storage)
 QVector<int> FeedList::feedIds() const
 {
     QVector<int> ids;
-    Q_FOREACH (const Feed *const i, feeds()) {
+    const auto f = feeds();
+    for (const Feed *const i : f) {
         ids += i->id();
     }
     return ids;
@@ -196,7 +197,8 @@ QVector<int> FeedList::feedIds() const
 QVector<const Feed *> FeedList::feeds() const
 {
     QVector<const Feed *> constList;
-    Q_FOREACH (const Feed *const i, d->rootNode->feeds()) {
+    const auto rootNodeFeeds = d->rootNode->feeds();
+    for (const Feed *const i : rootNodeFeeds) {
         constList.append(i);
     }
     return constList;
@@ -210,7 +212,8 @@ QVector<Feed *> FeedList::feeds()
 QVector<const Folder *> FeedList::folders() const
 {
     QVector<const Folder *> constList;
-    Q_FOREACH (const Folder *const i, d->rootNode->folders()) {
+    const auto nodeFolders = d->rootNode->folders();
+    for (const Folder *const i : nodeFolders) {
         constList.append(i);
     }
     return constList;
@@ -378,7 +381,8 @@ QDomDocument FeedList::toOpml() const
     QDomElement body = doc.createElement(QStringLiteral("body"));
     root.appendChild(body);
 
-    foreach (const TreeNode *const i, allFeedsFolder()->children()) {
+    const auto children = allFeedsFolder()->children();
+    for (const TreeNode *const i : children) {
         body.appendChild(i->toOPML(body, doc));
     }
 
@@ -534,7 +538,8 @@ QStringList FeedListManagementImpl::categories() const
         return QStringList();
     }
     QStringList cats;
-    Q_FOREACH (const Folder *const i, m_feedList->folders()) {
+    const auto folders = m_feedList->folders();
+    for (const Folder *const i : folders) {
         cats.append(path_of_folder(i));
     }
     return cats;
@@ -546,10 +551,11 @@ QStringList FeedListManagementImpl::feeds(const QString &catId) const
         return QStringList();
     }
 
-    uint lastcatid = catId.split(QLatin1Char('/'), QString::SkipEmptyParts).last().toUInt();
+    const uint lastcatid = catId.split(QLatin1Char('/'), QString::SkipEmptyParts).last().toUInt();
 
     QSet<QString> urls;
-    Q_FOREACH (const Feed *const i, m_feedList->feeds()) {
+    const auto feeds = m_feedList->feeds();
+    for (const Feed *const i : feeds) {
         if (lastcatid == i->parent()->id()) {
             urls.insert(i->xmlUrl());
         }
@@ -564,15 +570,15 @@ void FeedListManagementImpl::addFeed(const QString &url, const QString &catId)
     }
 
     qCDebug(AKREGATOR_LOG) << "Name:" << url.left(20) << "Cat:" << catId;
-    uint folder_id = catId.split(QLatin1Char('/'), QString::SkipEmptyParts).last().toUInt();
+    const uint folder_id = catId.split(QLatin1Char('/'), QString::SkipEmptyParts).last().toUInt();
 
     // Get the folder
     Folder *m_folder = nullptr;
-    QVector<Folder *> vector = m_feedList->folders();
+    const QVector<Folder *> vector = m_feedList->folders();
     for (int i = 0; i < vector.size(); ++i) {
         if (vector.at(i)->id() == folder_id) {
             m_folder = vector.at(i);
-            i = vector.size();
+            break;
         }
     }
 
@@ -596,7 +602,8 @@ void FeedListManagementImpl::removeFeed(const QString &url, const QString &catId
 
     uint lastcatid = catId.split(QLatin1Char('/'), QString::SkipEmptyParts).last().toUInt();
 
-    Q_FOREACH (const Feed *const i, m_feedList->feeds()) {
+    const auto feeds = m_feedList->feeds();
+    for (const Feed *const i : feeds) {
         if (lastcatid == i->parent()->id()) {
             if (i->xmlUrl().compare(url) == 0) {
                 qCDebug(AKREGATOR_LOG) << "id:" << i->id();
@@ -608,20 +615,6 @@ void FeedListManagementImpl::removeFeed(const QString &url, const QString &catId
     }
 }
 
-QString FeedListManagementImpl::addCategory(const QString &name, const QString &parentId) const
-{
-    Q_UNUSED(parentId)
-
-    if (!m_feedList) {
-        return QStringLiteral("");
-    }
-
-    Folder *m_folder = new Folder(name);
-    m_feedList->allFeedsFolder()->appendChild(m_folder);
-
-    return QString::number(m_folder->id());
-}
-
 QString FeedListManagementImpl::getCategoryName(const QString &catId) const
 {
     QString catname;
@@ -630,7 +623,7 @@ QString FeedListManagementImpl::getCategoryName(const QString &catId) const
         return catname;
     }
 
-    QStringList list = catId.split(QLatin1Char('/'), QString::SkipEmptyParts);
+    const QStringList list = catId.split(QLatin1Char('/'), QString::SkipEmptyParts);
     for (int i = 0; i < list.size(); ++i) {
         int index = list.at(i).toInt();
         catname += m_feedList->findByID(index)->title() + QLatin1Char('/');
